[nautilus-actions] Fix string errors reported by Christian Kirbach



commit c042ecc4d75521def67c2c743a338c2d1c8d8aa2
Author: Christian Kirbach <christian kirbach googlemail com>
Date:   Mon Jan 24 20:59:54 2011 +0100

    Fix string errors reported by Christian Kirbach
    
    Apply patch provided by Christian himself.
    Fix #640216.

 ChangeLog                                          |   40 ++++++++++++++++++++
 .../nautilus-actions-prefs.schemas.in              |    4 +-
 docs/des-ema/des-ema-0.15                          |   12 +++---
 docs/nact/C/nact-conditions.xml                    |   12 +++---
 docs/nact/C/nact-menus.xml                         |    2 +-
 src/api/na-extension.h                             |    4 +-
 src/api/na-ifactory-provider.h                     |   10 ++--
 src/api/na-iio-provider.h                          |   18 ++++----
 src/api/na-object.h                                |    2 +-
 src/core/na-core-utils.c                           |    4 +-
 src/core/na-factory-object.c                       |    2 +-
 src/core/na-gconf-utils.c                          |   14 +++---
 src/core/na-icontext-factory.c                     |    6 +-
 src/core/na-icontext.c                             |    2 +-
 src/core/na-ifactory-provider.c                    |    2 +-
 src/core/na-io-provider.c                          |    2 +-
 src/core/na-io-provider.h                          |    2 +-
 src/core/na-iprefs.c                               |    6 +-
 src/core/na-object-action.c                        |    4 +-
 src/core/na-object-id-factory.c                    |    8 ++--
 src/core/na-object-id.c                            |    2 +-
 src/core/na-object-item-factory.c                  |    2 +-
 src/core/na-object-item.c                          |    4 +-
 src/core/na-pivot.h                                |    6 +-
 src/core/na-settings.c                             |   12 +++---
 src/core/na-settings.h                             |    2 +-
 src/core/na-tokens.h                               |    2 +-
 src/io-desktop/nadp-desktop-file.c                 |   10 ++--
 src/io-desktop/nadp-reader.c                       |    2 +-
 src/io-desktop/nadp-utils.c                        |    2 +-
 src/io-gconf/nagp-reader.c                         |    2 +-
 src/io-xml/naxml-reader.c                          |    8 ++--
 src/nact/nact-gtk-utils.c                          |    6 +-
 src/nact/nautilus-actions-config-tool.ui           |   24 ++++++------
 src/plugin-menu/nautilus-actions.c                 |    2 +-
 src/utils/nautilus-actions-new.c                   |    2 +-
 src/utils/nautilus-actions-run.c                   |    2 +-
 tools/check-headers.sh                             |    2 +-
 tools/init-finalize-diff.sh                        |    8 ++--
 39 files changed, 148 insertions(+), 108 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index b879a14..fa00b09 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,45 @@
 2011-01-24 Pierre Wieser <pwieser trychlos org>
 
+	* data/gconf-schemas/nautilus-actions-prefs.schemas.in:
+	* docs/des-ema/des-ema-0.15:
+	* docs/nact/C/nact-conditions.xml:
+	* docs/nact/C/nact-menus.xml:
+	* src/api/na-extension.h:
+	* src/api/na-ifactory-provider.h:
+	* src/api/na-iio-provider.h:
+	* src/api/na-object.h:
+	* src/core/na-core-utils.c:
+	* src/core/na-factory-object.c:
+	* src/core/na-gconf-utils.c:
+	* src/core/na-icontext-factory.c:
+	* src/core/na-icontext.c:
+	* src/core/na-ifactory-provider.c:
+	* src/core/na-io-provider.c:
+	* src/core/na-io-provider.h:
+	* src/core/na-iprefs.c:
+	* src/core/na-object-action.c:
+	* src/core/na-object-id-factory.c:
+	* src/core/na-object-id.c:
+	* src/core/na-object-item-factory.c:
+	* src/core/na-object-item.c:
+	* src/core/na-pivot.h:
+	* src/core/na-settings.c:
+	* src/core/na-settings.h:
+	* src/core/na-tokens.h:
+	* src/io-desktop/nadp-desktop-file.c:
+	* src/io-desktop/nadp-reader.c:
+	* src/io-desktop/nadp-utils.c:
+	* src/io-gconf/nagp-reader.c:
+	* src/io-xml/naxml-reader.c:
+	* src/nact/nact-gtk-utils.c:
+	* src/nact/nautilus-actions-config-tool.ui:
+	* src/plugin-menu/nautilus-actions.c:
+	* src/utils/nautilus-actions-new.c:
+	* src/utils/nautilus-actions-run.c:
+	* tools/check-headers.sh:
+	* tools/init-finalize-diff.sh:
+	Apply patch provided by Christian Kirbach. Fix #640216.
+
 	* src/nact/nautilus-actions-config-tool.ui:
 	* src/utils/na-delete-xmltree.c:
 	* src/utils/nautilus-actions-print.c:
diff --git a/data/gconf-schemas/nautilus-actions-prefs.schemas.in b/data/gconf-schemas/nautilus-actions-prefs.schemas.in
index 9946cee..23d9b66 100644
--- a/data/gconf-schemas/nautilus-actions-prefs.schemas.in
+++ b/data/gconf-schemas/nautilus-actions-prefs.schemas.in
@@ -428,7 +428,7 @@ As the order of items is also locked, the level zero itself cannot be modified,
       <type>bool</type>
       <locale name="C">
         <short>Whether the GConf I/O provider is locked</short>
-        <long>When set to true (most probably as a mandatory key), this prevents all items, menus and actions, readen from GConf to being modified in NACT.</long>
+        <long>When set to true (most probably as a mandatory key), this prevents all items, menus and actions, read from GConf to being modified in NACT.</long>
       </locale>
       <default>false</default>
     </schema>
@@ -439,7 +439,7 @@ As the order of items is also locked, the level zero itself cannot be modified,
       <type>bool</type>
       <locale name="C">
         <short>Whether the Desktop I/O provider is locked</short>
-        <long>When set to true (most probably as a mandatory key), this prevents all items, menus and actions, readen from .desktop files to being modified in NACT.</long>
+        <long>When set to true (most probably as a mandatory key), this prevents all items, menus and actions, read from .desktop files to being modified in NACT.</long>
       </locale>
       <default>false</default>
     </schema>
diff --git a/docs/des-ema/des-ema-0.15 b/docs/des-ema/des-ema-0.15
index da78e06..2ec0bf3 100644
--- a/docs/des-ema/des-ema-0.15
+++ b/docs/des-ema/des-ema-0.15
@@ -541,9 +541,9 @@ When an element of the string list is negated, it must be considered as an AND c
 <p>Example:</p>
 <blockquote>
  <p>
- The line &laquo;&nbsp;<?php code( "MimeTypes = image/*; video/*;" ); ?>&nbsp;&raquo; must be readen as &laquo;&nbsp;condition is met if each file in the current selection has a mimetype of "<?php code( "image/*" ); ?>" or of "<?php code( "video/*" ); ?>"&nbsp;&raquo;
+ The line &laquo;&nbsp;<?php code( "MimeTypes = image/*; video/*;" ); ?>&nbsp;&raquo; must be read as &laquo;&nbsp;condition is met if each file in the current selection has a mimetype of "<?php code( "image/*" ); ?>" or of "<?php code( "video/*" ); ?>"&nbsp;&raquo;
   </p>
-  <p>And the line &laquo;&nbsp;<?php code( "MimeTypes = image/*; video/*; !image/bmp" ); ?>&nbsp;&raquo; must be readen as &laquo;&nbsp;condition is met if each file in the current selection has a mimetype of "<?php code( "image/*" ); ?>" or of "<?php code( "video/*" ); ?>", but must not have the "<?php code( "image/bmp" ); ?>" mimetype&nbsp;&raquo;.
+  <p>And the line &laquo;&nbsp;<?php code( "MimeTypes = image/*; video/*; !image/bmp" ); ?>&nbsp;&raquo; must be read as &laquo;&nbsp;condition is met if each file in the current selection has a mimetype of "<?php code( "image/*" ); ?>" or of "<?php code( "video/*" ); ?>", but must not have the "<?php code( "image/bmp" ); ?>" mimetype&nbsp;&raquo;.
   </p>
 </blockquote>
 
@@ -729,7 +729,7 @@ Capabilities may be negated.<br />
 Please note that each element of the specified list must be considered as ANDed, i.e. if we have "<?php code( "Capabilities=Readable;Writable;!Local" ); ?>", then each element of the selection must be both readable AND writable AND not local.<br />
 Capabilities have to be choosen between following predefined ones:
 <ul>
-<li>"<?php code( "Owner" ); ?>": current user is the owner of selected items</li>
+<li>"<?php code( "Owner" ); ?>": current user is the owner of the selected items</li>
 <li>"<?php code( "Readable" ); ?>": selected items are readable by user (probably more usefull when negated)</li>
 <li>"<?php code( "Writable" ); ?>": selected items are writable by user</li>
 <li>"<?php code( "Executable" ); ?>": selected items are executable by user</li>
@@ -827,10 +827,10 @@ Example:
   <p>
   If the <?php code( "Exec" ); ?> key is "<?php code( "echo %B %b" ); ?>", then the following commands will be run:<br />
        "<?php code( "echo pierre paul jacques pierre" ); ?>"<br />
-  The basename used is those of the first item of the selected items list as provided by the file manager. There is only a small chance that it would be those of the first visually selected item, and there is contrarily great chances that it would not be predictable at all.
+  The basename used is the one of the first item of the selected items list as provided by the file manager. There is only a small chance that it would be those of the first visually selected item, and there is contrarily great chances that it would not be predictable at all.
   </p>
   <p>
-   Even if the choosen parameter is the same for all selected items, the behavior is the identical.<br />
+   Even if the chosen parameter is the same for all selected items, the behavior is identical.<br />
    If the <?php code( "Exec" ); ?> key is "<?php code( "echo %d %B" ); ?>", then the following commands will be run:<br />
        "<?php code( "echo /data pierre paul jacques" ); ?>"<br />
        "<?php code( "echo /data pierre paul jacques" ); ?>"<br />
@@ -1128,7 +1128,7 @@ The <?php code( "[Desktop Entry]" ); ?> section of this <?php code( "level-zero.
 The <?php code( "level-zero.directory" ); ?> file may be searched for in <?php code( "XDG_DATA_DIRS/file-manager/actions" ); ?>. The first one found would be used.
 </p>
 <p>
-Not finding a <?php code( "level-zero.directory" ); ?> file should not prevent actions or menus to be displayed. Instead, they just would be displayed in an unspecified, implementation-dependant, order.
+Not finding a <?php code( "level-zero.directory" ); ?> file should not prevent actions or menus to be displayed. Instead, they just would be displayed in an unspecified, implementation-dependent, order.
 </p>
 <p>
 The name "<?php code( "level-zero.directory" ); ?>" is choosen to not risk any collision with regular <?php desktop(); ?> files.
diff --git a/docs/nact/C/nact-conditions.xml b/docs/nact/C/nact-conditions.xml
index 095cd70..bf03230 100644
--- a/docs/nact/C/nact-conditions.xml
+++ b/docs/nact/C/nact-conditions.xml
@@ -2,7 +2,7 @@
   <title>Defining the conditions</title>
   <para>
     Whether your action will eventually be displayed in &nautilus; file manager
-    context menus or in its toolbar depends of the conditions you will have
+    context menus or in its toolbar depends on the conditions you will have
     defined for it.
   </para>
   <para>
@@ -121,7 +121,7 @@
       </listitem>
       <listitem>
         <para>
-          When disactivated, filters are considered as case insensitive,
+          When deactivated, filters are considered as case insensitive,
           which means that <filename>/my/file</filename> and
           <filename>/My/File</filename> filenames are considered the same
           name.
@@ -384,7 +384,7 @@
           <listitem>
             <para>
               Or click on
-              <guibutton>Browse</guibutton> to select a folder on the filesystem.
+              <guibutton>Browse</guibutton> to select a folder on the file system.
             </para>
           </listitem>
         </itemizedlist>
@@ -404,7 +404,7 @@
     <para>
       By default, the folder-based condition is just one
       &laquosp;<literal>must match one of /</literal>&spraquo; condition.
-      As <literal>/</literal> is always the top of an Unix-like filesystem,
+      As <literal>/</literal> is always the top of an Unix-like file system,
       then all selected items always match this condition.
     </para>
     <note>
@@ -508,7 +508,7 @@
                     <imagedata fileref="figures/nact-new-scheme.png" format="PNG"/>
                   </imageobject>
                   <textobject>
-                    <phrase>Show the list of predefined schemess.</phrase>
+                    <phrase>Show the list of predefined schemes.</phrase>
                   </textobject>
                   <caption>
                     <para>Selecting a scheme among predefined defaults</para>
@@ -551,7 +551,7 @@
       Capabilities are some properties that a file may exhibit to the user.
     </para>
     <para>
-      But the <literal>Local</literal> capability, all others are dependant
+      But the <literal>Local</literal> capability, all others are dependent
       of the user who executes the command.
     </para>
     <para>
diff --git a/docs/nact/C/nact-menus.xml b/docs/nact/C/nact-menus.xml
index a34f386..be2b2fb 100644
--- a/docs/nact/C/nact-menus.xml
+++ b/docs/nact/C/nact-menus.xml
@@ -17,7 +17,7 @@
   </para>
   <para>
     As an action, the exact place where a new menu will be inserted
-    depends of the current sort order:
+    depends on the current sort order:
   </para>
   <variablelist>
     <varlistentry>
diff --git a/src/api/na-extension.h b/src/api/na-extension.h
index 1fe580d..6728967 100644
--- a/src/api/na-extension.h
+++ b/src/api/na-extension.h
@@ -198,7 +198,7 @@ G_BEGIN_DECLS
  *   </programlisting>
  * </example>
  *
- * Returns: %TRUE if the initialization is successfull, %FALSE else.
+ * Returns: %TRUE if the initialization is successful, %FALSE else.
  * In this later case, the library is unloaded and no more considered.
  *
  * Since: 2.30
@@ -279,7 +279,7 @@ guint    na_extension_list_types ( const GType **types );
  * This function is called by Nautilus-Actions when it is about to
  * shutdown itself.
  *
- * The dynamicaly loaded library may take advantage of this call to
+ * The dynamically loaded library may take advantage of this call to
  * release any resource, handle, and so on, it may have previously
  * allocated.
  *
diff --git a/src/api/na-ifactory-provider.h b/src/api/na-ifactory-provider.h
index a2a8a68..8fccf0a 100644
--- a/src/api/na-ifactory-provider.h
+++ b/src/api/na-ifactory-provider.h
@@ -89,7 +89,7 @@
  *
  * Without this interface, each and every I/O provider must,
  * for example when reading an item, have the list of data to be
- * readen for each item, then read each individual data, then
+ * read for each item, then read each individual data, then
  * organize them in a I/O structure..
  * Each time a new data is added to an object, as e.g. a new condition,
  * then all available I/O providers must be updated: read the data,
@@ -183,7 +183,7 @@ typedef struct {
 	 * @reader: this #NAIFactoryProvider instance.
 	 * @reader_data: the data associated to this instance, as provided
 	 *  when na_ifactory_provider_read_item() was called.
-	 * @object: the #NAIFactoryObject object which comes to be readen.
+	 * @object: the #NAIFactoryObject object which comes to be read.
 	 * @messages: a pointer to a #GSList list of strings; the provider
 	 *  may append messages to this list, but shouldn't reinitialize it.
 	 *
@@ -205,7 +205,7 @@ typedef struct {
 	 *
 	 * This method must be implemented in order any data be read.
 	 *
-	 * Returns: a newly allocated NADataBoxed which contains the readen value.
+	 * Returns: a newly allocated NADataBoxed which contains the read value.
 	 * Should return %NULL if data is not found.
 	 *
 	 * Since: 2.30
@@ -217,11 +217,11 @@ typedef struct {
 	 * @reader: this #NAIFactoryProvider instance.
 	 * @reader_data: the data associated to this instance, as provided
 	 *  when na_ifactory_provider_read_item() was called.
-	 * @object: the #NAIFactoryObject object which comes to be readen.
+	 * @object: the #NAIFactoryObject object which comes to be read.
 	 * @messages: a pointer to a #GSList list of strings; the provider
 	 *  may append messages to this list, but shouldn't reinitialize it.
 	 *
-	 * API called by #NAIFactoryObject when all data have been readen.
+	 * API called by #NAIFactoryObject when all data have been read.
 	 * Implementor may take advantage of this to do some cleanup.
 	 *
 	 * Since: 2.30
diff --git a/src/api/na-iio-provider.h b/src/api/na-iio-provider.h
index 178ee15..7fe2b2f 100644
--- a/src/api/na-iio-provider.h
+++ b/src/api/na-iio-provider.h
@@ -229,18 +229,18 @@ typedef struct {
 	 *
 	 * The 'able_to_write' property is a runtime one.
 	 * When returning %TRUE, the I/O provider insures that it has
-	 * sucessfully checked that it was able to write some things
+	 * successfully checked that it was able to write some things
 	 * down to its storage subsystems.
 	 *
-	 * The 'able_to_write' property is independant of the
+	 * The 'able_to_write' property is independent of the
 	 * 'willing_to_write' above, though it is only checked if the
 	 * I/O provider is actually willing to write.
 	 *
 	 * This condition is only relevant when trying to define new items,
 	 * to see if a willing_to provider is actually able to do write
 	 * operations. It it not relevant for updating/deleting already
-	 * existings items as they have already checked their own runtime
-	 * writability status when readen from the storage subsystems.
+	 * existing items as they have already checked their own runtime
+	 * writability status when read from the storage subsystems.
 	 *
 	 * Note that even if this property is %TRUE, there is yet many
 	 * reasons for not being able to update/delete existing items or
@@ -264,7 +264,7 @@ typedef struct {
 	 *
 	 * Writes a new @item.
 	 *
-	 * There is no update_item function ; it is the responsability
+	 * There is no update_item function ; it is the responsibility
 	 * of the provider to delete the previous version of an item before
 	 * actually writing the new one.
 	 *
@@ -272,7 +272,7 @@ typedef struct {
 	 * %FALSE in is_willing_to_write() method above.
 	 *
 	 * Returns: %NA_IIO_PROVIDER_CODE_OK if the write operation
-	 * was successfull, or another code depending of the detected error.
+	 * was successful, or another code depending of the detected error.
 	 *
 	 * Since: 2.30
 	 */
@@ -291,7 +291,7 @@ typedef struct {
 	 * %FALSE in is_willing_to_write() method above.
 	 *
 	 * Returns: %NA_IIO_PROVIDER_CODE_OK if the delete operation was
-	 * successfull, or another code depending of the detected error.
+	 * successful, or another code depending of the detected error.
 	 *
 	 * Since: 2.30
 	 */
@@ -312,7 +312,7 @@ typedef struct {
 	 * data which may have been attached to a #NAObjectItem -derived object.
 	 *
 	 * Returns: %NA_IIO_PROVIDER_CODE_OK if the duplicate operation was
-	 * successfull, or another code depending of the detected error.
+	 * successful, or another code depending of the detected error.
 	 *
 	 * Since: 2.30
 	 */
@@ -334,7 +334,7 @@ void  na_iio_provider_item_changed ( const NAIIOProvider *instance );
  */
 /**
  * NAIIOProviderWritabilityStatus:
- * @NA_IIO_PROVIDER_STATUS_UNDETERMINED:             undertermined.
+ * @NA_IIO_PROVIDER_STATUS_UNDETERMINED:             undetermined.
  * @NA_IIO_PROVIDER_STATUS_WRITABLE:                 the item is writable.
  * @NA_IIO_PROVIDER_STATUS_ITEM_READONLY:            the item is read-only.
  * @NA_IIO_PROVIDER_STATUS_PROVIDER_NOT_WILLING_TO:  the provider is not willing to write this item,
diff --git a/src/api/na-object.h b/src/api/na-object.h
index 43b518e..257b973 100644
--- a/src/api/na-object.h
+++ b/src/api/na-object.h
@@ -139,7 +139,7 @@ typedef struct {
 	 *
 	 * Checks @object for validity.
 	 *
-	 * A NAObject is valid if its internal identifiant is set.
+	 * A NAObject is valid if its internal identifier is set.
 	 *
 	 * Each derived class should take care of implementing this function
 	 * when relevant. NAObject class will take care of calling this
diff --git a/src/core/na-core-utils.c b/src/core/na-core-utils.c
index 20b28f4..7a8953c 100644
--- a/src/core/na-core-utils.c
+++ b/src/core/na-core-utils.c
@@ -970,10 +970,10 @@ na_core_utils_file_exists( const gchar *uri )
 /**
  * na_core_utils_file_load_from_uri:
  * @uri: the URI the file must be loaded from.
- * @length: a pointer to the length of the readen content.
+ * @length: a pointer to the length of the read content.
  *
  * Loads the file into a newly allocated buffer, and set up the length of the
- * readen content if not %NULL.
+ * read content if not %NULL.
  *
  * Returns: the newly allocated buffer which contains the file content, or %NULL.
  * This buffer should be g_free() by the caller.
diff --git a/src/core/na-factory-object.c b/src/core/na-factory-object.c
index c62116a..cc8ac09 100644
--- a/src/core/na-factory-object.c
+++ b/src/core/na-factory-object.c
@@ -740,7 +740,7 @@ write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIt
  * Set the @value with the current content of the #NADataBoxed attached
  * to @name.
  *
- * This is to be readen as "set value from data element".
+ * This is to be read as "set value from data element".
  */
 void
 na_factory_object_get_as_value( const NAIFactoryObject *object, const gchar *name, GValue *value )
diff --git a/src/core/na-gconf-utils.c b/src/core/na-gconf-utils.c
index fd817ab..4bc3450 100644
--- a/src/core/na-gconf-utils.c
+++ b/src/core/na-gconf-utils.c
@@ -44,7 +44,7 @@ static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
 /**
  * na_gconf_utils_get_subdirs:
  * @gconf: a GConfClient instance.
- * @path: a full path to be readen.
+ * @path: a full path to be read.
  *
  * Returns: a list of full path subdirectories.
  *
@@ -120,7 +120,7 @@ na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
 /**
  * na_gconf_utils_get_entries:
  * @gconf: a  GConfClient instance.
- * @path: a full path to be readen.
+ * @path: a full path to be read.
  *
  * Loads all the key=value pairs of the specified key.
  *
@@ -533,7 +533,7 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
  *
  * Writes a boolean at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
@@ -572,7 +572,7 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
  *
  * Writes an integer at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
@@ -611,7 +611,7 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
  *
  * Writes a string at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
@@ -650,7 +650,7 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
  *
  * Writes a list of strings at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
@@ -693,7 +693,7 @@ na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList
  *
  * Removes an entry from user preferences.
  *
- * Returns: %TRUE if the operation was successfull, %FALSE else.
+ * Returns: %TRUE if the operation was successful, %FALSE else.
  *
  * Since: 2.30
  *
diff --git a/src/core/na-icontext-factory.c b/src/core/na-icontext-factory.c
index 10bd2c5..6c58d80 100644
--- a/src/core/na-icontext-factory.c
+++ b/src/core/na-icontext-factory.c
@@ -48,7 +48,7 @@ NADataDef data_def_conditions [] = {
 				/* i18n: wildcard characters '*' and '?' should be considered as literalls,
 				 *  and not be translated */
 				N_( "A list of strings with joker '*' or '?' to be matched against the name(s) " \
-					"of the selected file(s)/folder(s). Each selected items must match at least " \
+					"of the selected file(s)/folder(s). Each selected item must match at least " \
 					"one of the filename patterns for the action or the menu be candidate to " \
 					"display.\n" \
 					"This obviously only applies when there is a selection.\n" \
@@ -110,7 +110,7 @@ NADataDef data_def_conditions [] = {
 				N_( "List of patterns to be matched against the mimetypes of the selected file(s)/folder(s)" ),
 				/* i18n: wildcard character '*' is taken literally, and should not be translated */
 				N_( "A list of strings with joker '*' to be matched against the mimetypes of the " \
-					"selected file(s)/folder(s). Each selected items must match at least one of " \
+					"selected file(s)/folder(s). Each selected item must match at least one of " \
 					"the mimetype patterns for the action to appear.\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to '*/*'." ),
@@ -502,7 +502,7 @@ NADataDef data_def_conditions [] = {
 				N_( "Capabilities" ),
 				/* i18n: 'Owner', 'Readable', 'Writable', 'Executable' and 'Local' are all keywords
 				 *  of the specification, they are not translatable */
-				N_( "A list of capabilities each item of the selection must satisfy in order the item be candidate.\n" \
+				N_( "A list of capabilities each item of the selection must satisfy in order for the item to be candidate.\n" \
 					"Capabilities may be negated.\n" \
 					"Capabilities have to be choosen between following predefined ones:\n" \
 					"- 'Owner': current user is the owner of selected items\n" \
diff --git a/src/core/na-icontext.c b/src/core/na-icontext.c
index f1e852a..1ee2316 100644
--- a/src/core/na-icontext.c
+++ b/src/core/na-icontext.c
@@ -295,7 +295,7 @@ na_icontext_is_all_mimetypes( const NAIContext *context )
  * na_icontext_read_done:
  * @context: the #NAIContext to be prepared.
  *
- * Prepares the specified #NAIContext just after it has been readen.
+ * Prepares the specified #NAIContext just after it has been read.
  *
  * <itemizedlist>
  *   <listitem>
diff --git a/src/core/na-ifactory-provider.c b/src/core/na-ifactory-provider.c
index 660bf95..917cd48 100644
--- a/src/core/na-ifactory-provider.c
+++ b/src/core/na-ifactory-provider.c
@@ -166,7 +166,7 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
  * <example>
  *   <programlisting>
  *     &lcomment;
- *      * allocate the object to be readen
+ *      * allocate the object to be read
  *      &rcomment;
  *     NAObjectItem *item = NA_OBJECT_ITEM( na_object_action_new());
  *     &lcomment;
diff --git a/src/core/na-io-provider.c b/src/core/na-io-provider.c
index 6906d97..52fe556 100644
--- a/src/core/na-io-provider.c
+++ b/src/core/na-io-provider.c
@@ -1006,7 +1006,7 @@ load_items_filter_unwanted_items_rec( GList *hierarchy, guint loadable_set )
 }
 
 /*
- * returns a concatened flat list of readen actions / menus
+ * returns a concatened flat list of read actions / menus
  * we take care here of:
  * - i/o providers which appear unavailable at runtime
  * - i/o providers marked as unreadable
diff --git a/src/core/na-io-provider.h b/src/core/na-io-provider.h
index cb9f038..8742127 100644
--- a/src/core/na-io-provider.h
+++ b/src/core/na-io-provider.h
@@ -45,7 +45,7 @@
  * corresponding NAIOProvider class method.
  *
  * Two preferences are used for each i/o provider:
- * 'readable': means that the i/o provider should be readen when building
+ * 'readable': means that the i/o provider should be read when building
  *  the items hierarchy
  * 'writable': means that the i/o provider is candidate when writing a
  *  new item; this also means that existing items are deletable.
diff --git a/src/core/na-iprefs.c b/src/core/na-iprefs.c
index b1572fb..65ce8fb 100644
--- a/src/core/na-iprefs.c
+++ b/src/core/na-iprefs.c
@@ -82,7 +82,7 @@ static guint        enum_map_id_from_string( const EnumMap *map, const gchar *st
 /*
  * na_iprefs_get_import_mode:
  * @pivot: the #NAPivot application object.
- * @pref: name of the import key to be readen.
+ * @pref: name of the import key to be read.
  * @mandatory: if not %NULL, a pointer to a boolean which will receive the
  *  mandatory property.
  *
@@ -171,7 +171,7 @@ na_iprefs_set_order_mode( const NAPivot *pivot, guint mode )
 /**
  * na_iprefs_get_export_format:
  * @pivot: the #NAPivot application object.
- * @name: name of the export format key to be readen
+ * @name: name of the export format key to be read
  * @mandatory: if not %NULL, a pointer to a boolean which will receive the
  *  mandatory property.
  *
@@ -224,7 +224,7 @@ na_iprefs_set_export_format( const NAPivot *pivot, const gchar *name, GQuark for
  * This does not mean in any way that the i/o provider is active,
  * available or so, but just that is mentioned here.
  *
- * I/o provider identifers returned in the list are not supposed
+ * I/o provider identifiers returned in the list are not supposed
  * to be unique, nor sorted.
  *
  * Returns: a list of i/o provider identifiers found in preferences
diff --git a/src/core/na-object-action.c b/src/core/na-object-action.c
index d303f10..58b2f13 100644
--- a/src/core/na-object-action.c
+++ b/src/core/na-object-action.c
@@ -327,7 +327,7 @@ ifactory_object_is_valid( const NAIFactoryObject *object )
 }
 
 /*
- * at this time, we don't yet have readen the profiles as this will be
+ * at this time, we don't yet have read the profiles as this will be
  * done in ifactory_provider_read_done - we so just be able to deal with
  * action-specific properties (not check for profiles consistency)
  */
@@ -406,7 +406,7 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
  *  any data found in data_def_action_v1 (defined in na-object-action-factory.c)
  *  is obsoleted and moved to a new profile
  *
- * actions readen from .desktop already have iversion=3 (cf. desktop_read_start)
+ * actions read from .desktop already have iversion=3 (cf. desktop_read_start)
  * and v1 actions may only come from xml or gconf
  *
  * returns TRUE if this actually was a v1 action which has been converted to v2
diff --git a/src/core/na-object-id-factory.c b/src/core/na-object-id-factory.c
index 1872c49..c32cd47 100644
--- a/src/core/na-object-id-factory.c
+++ b/src/core/na-object-id-factory.c
@@ -38,15 +38,15 @@
 
 NADataDef data_def_id [] = {
 
-	/* this data is marked non readable / non writable as it has to be readen
-	 * written specifically when serializing / unserializing items
+	/* this data is marked non readable / non writable as it has to be read
+	 * written specifically when serializing / deserializing items
 	 */
 	{ NAFO_DATA_ID,
 				FALSE,
 				FALSE,
 				TRUE,
-				"NAObjectId identifiant",
-				"Internal identifiant of the NAObjectId object. " \
+				"NAObjectId identifier",
+				"Internal identifier of the NAObjectId object. " \
 				"Historically a UUID used as a GConf directory (thus ASCII, case insensitive), " \
 				"it is also the basename of the .desktop file (thus UTF-8, case sensitive).",
 				NAFD_TYPE_STRING,
diff --git a/src/core/na-object-id.c b/src/core/na-object-id.c
index 64ca258..fe6ad07 100644
--- a/src/core/na-object-id.c
+++ b/src/core/na-object-id.c
@@ -371,7 +371,7 @@ na_object_id_set_copy_of_label( NAObjectId *object )
 
 /**
  * na_object_id_set_new_id:
- * @object: the #NAObjectId object whose internal identifiant is to be
+ * @object: the #NAObjectId object whose internal identifier is to be
  * set.
  * @new_parent: if @object is a #NAObjectProfile, then @new_parent
  * should be set to the #NAObjectAction new parent. Else, it would not
diff --git a/src/core/na-object-item-factory.c b/src/core/na-object-item-factory.c
index 16bc35c..1e3b227 100644
--- a/src/core/na-object-item-factory.c
+++ b/src/core/na-object-item-factory.c
@@ -40,7 +40,7 @@
 
 NADataDef data_def_item [] = {
 
-	/* this data is marked as non readable as it has to be readen specifically
+	/* this data is marked as non readable as it has to be read specifically
 	 * in order to be able to create the corresponding NAObjectItem-derived
 	 * object
 	 * it is not writable as different I/O providers may have different values
diff --git a/src/core/na-object-item.c b/src/core/na-object-item.c
index 376a51a..12f2319 100644
--- a/src/core/na-object-item.c
+++ b/src/core/na-object-item.c
@@ -716,12 +716,12 @@ na_object_item_unref_items_rec( GList *items )
  * na_object_item_deals_with_version:
  * @item: this #NAObjectItem -derived object.
  *
- * Just after the @item has been readen from NAIFactoryProvider, setup
+ * Just after the @item has been read from NAIFactoryProvider, setup
  * the version. This is needed because some conversions may occur in
  * this object.
  *
  * Note that there is only some 2.x versions where the version string
- * was not systematically written. If @item has been readen from a
+ * was not systematically written. If @item has been read from a
  * .desktop file, then iversion is already set to (at least) 3.
  *
  * Since: 2.30
diff --git a/src/core/na-pivot.h b/src/core/na-pivot.h
index 7bdefe7..d81bbf4 100644
--- a/src/core/na-pivot.h
+++ b/src/core/na-pivot.h
@@ -48,7 +48,7 @@
  *
  * Each I/O storage provider should monitor modifications/deletions of
  * actions, and advertize this #NAPivot, which itself will then
- * advertize any registered consumers.
+ * advertise any registered consumers.
  *
  * This notification system is so a double-stage one :
  *
@@ -71,7 +71,7 @@
  *    updates.
  *
  * 2. When #NAPivot has successfully updated its list of actions, it
- *    notifies its consumers in order they update themselves.
+ *    notifies its consumers so they update themselves.
  *
  *    Note that #NAPivot tries to factorize notification messages, and
  *    to notify its consumers only once even if it has itself received
@@ -120,7 +120,7 @@ GType    na_pivot_get_type( void );
 
 /* signals
  *
- * NAPivot acts as a 'sumarrizing' proxy for signals emitted by the NAIIOProvider
+ * NAPivot acts as a 'summarizing' proxy for signals emitted by the NAIIOProvider
  * providers when they detect a modification of their underlying items storage
  * subsystems.
  * As several to many signals may be emitted when such a modification occurs,
diff --git a/src/core/na-settings.c b/src/core/na-settings.c
index 0574481..9f9c6e5 100644
--- a/src/core/na-settings.c
+++ b/src/core/na-settings.c
@@ -423,7 +423,7 @@ na_settings_register_global_callback( NASettings *settings, GCallback callback,
  *  whether the searched @key has been found (%TRUE), or if the returned
  *  value comes from default (%FALSE).
  * @mandatory: if not %NULL, a pointer to a gboolean in which we will store
- *  whether the returned value has been readen from mandatory preferences
+ *  whether the returned value has been read from mandatory preferences
  *  (%TRUE), or from the user preferences (%FALSE). When the @key has not
  *  been found, @mandatory is set to %FALSE.
  *
@@ -449,7 +449,7 @@ na_settings_get_boolean( NASettings *settings, const gchar *key, gboolean *found
  *  whether the searched @key has been found (%TRUE), or if the returned
  *  value comes from default (%FALSE).
  * @mandatory: if not %NULL, a pointer to a gboolean in which we will store
- *  whether the returned value has been readen from mandatory preferences
+ *  whether the returned value has been read from mandatory preferences
  *  (%TRUE), or from the user preferences (%FALSE). When the @key has not
  *  been found, @mandatory is set to %FALSE.
  *
@@ -489,7 +489,7 @@ na_settings_get_boolean_ex( NASettings *settings, const gchar *group, const gcha
  *  whether the searched @key has been found (%TRUE), or if the returned
  *  value comes from default (%FALSE).
  * @mandatory: if not %NULL, a pointer to a gboolean in which we will store
- *  whether the returned value has been readen from mandatory preferences
+ *  whether the returned value has been read from mandatory preferences
  *  (%TRUE), or from the user preferences (%FALSE). When the @key has not
  *  been found, @mandatory is set to %FALSE.
  *
@@ -533,7 +533,7 @@ na_settings_get_string( NASettings *settings, const gchar *key, gboolean *found,
  *  whether the searched @key has been found (%TRUE), or if the returned
  *  value comes from default (%FALSE).
  * @mandatory: if not %NULL, a pointer to a gboolean in which we will store
- *  whether the returned value has been readen from mandatory preferences
+ *  whether the returned value has been read from mandatory preferences
  *  (%TRUE), or from the user preferences (%FALSE). When the @key has not
  *  been found, @mandatory is set to %FALSE.
  *
@@ -577,7 +577,7 @@ na_settings_get_string_list( NASettings *settings, const gchar *key, gboolean *f
  *  whether the searched @key has been found (%TRUE), or if the returned
  *  value comes from default (%FALSE).
  * @mandatory: if not %NULL, a pointer to a gboolean in which we will store
- *  whether the returned value has been readen from mandatory preferences
+ *  whether the returned value has been read from mandatory preferences
  *  (%TRUE), or from the user preferences (%FALSE). When the @key has not
  *  been found, @mandatory is set to %FALSE.
  *
@@ -620,7 +620,7 @@ na_settings_get_uint( NASettings *settings, const gchar *key, gboolean *found, g
  *  whether the searched @key has been found (%TRUE), or if the returned
  *  value comes from default (%FALSE).
  * @mandatory: if not %NULL, a pointer to a gboolean in which we will store
- *  whether the returned value has been readen from mandatory preferences
+ *  whether the returned value has been read from mandatory preferences
  *  (%TRUE), or from the user preferences (%FALSE). When the @key has not
  *  been found, @mandatory is set to %FALSE.
  *
diff --git a/src/core/na-settings.h b/src/core/na-settings.h
index 96b66d9..65bc05e 100644
--- a/src/core/na-settings.h
+++ b/src/core/na-settings.h
@@ -47,7 +47,7 @@
  * - per-user configuration is HOME/.config/nautilus-actions.conf
  *
  * Each setting has so its own read-only attribute, whether it
- * has been readen from the global configuration or from the
+ * has been read from the global configuration or from the
  * per-user one.
  */
 
diff --git a/src/core/na-tokens.h b/src/core/na-tokens.h
index 90f6015..c90a2bc 100644
--- a/src/core/na-tokens.h
+++ b/src/core/na-tokens.h
@@ -60,7 +60,7 @@
  * %B: space-separated list of basenames
  * %c: count of selected items
  * %d: (first) base directory
- * %D: space-separated list of base directory of each selected items
+ * %D: space-separated list of base directory of each selected item
  * %f: (first) file name
  * %F: space-separated list of selected file names
  * %h: hostname of the (first) URI
diff --git a/src/io-desktop/nadp-desktop-file.c b/src/io-desktop/nadp-desktop-file.c
index 023e6ad..50184e1 100644
--- a/src/io-desktop/nadp-desktop-file.c
+++ b/src/io-desktop/nadp-desktop-file.c
@@ -662,7 +662,7 @@ nadp_desktop_file_remove_profile( const NadpDesktopFile *ndf, const gchar *profi
  * @key_found: set to %TRUE if the key has been found, to %FALSE else.
  * @default_value: value to be set if key has not been found.
  *
- * Returns: the readen value, or the default value if the entry has not
+ * Returns: the read value, or the default value if the entry has not
  * been found in the given group.
  */
 gboolean
@@ -711,7 +711,7 @@ nadp_desktop_file_get_boolean( const NadpDesktopFile *ndf, const gchar *group, c
  * @key_found: set to %TRUE if the key has been found, to %FALSE else.
  * @default_value: value to be set if key has not been found.
  *
- * Returns: the readen value, or the default value if the entry has not
+ * Returns: the read value, or the default value if the entry has not
  * been found in the given group.
  */
 gchar *
@@ -757,7 +757,7 @@ nadp_desktop_file_get_locale_string( const NadpDesktopFile *ndf, const gchar *gr
  * @key_found: set to %TRUE if the key has been found, to %FALSE else.
  * @default_value: value to be set if key has not been found.
  *
- * Returns: the readen value, or the default value if the entry has not
+ * Returns: the read value, or the default value if the entry has not
  * been found in the given group.
  */
 gchar *
@@ -808,7 +808,7 @@ nadp_desktop_file_get_string( const NadpDesktopFile *ndf, const gchar *group, co
  * @key_found: set to %TRUE if the key has been found, to %FALSE else.
  * @default_value: value to be set if key has not been found.
  *
- * Returns: the readen value, or the default value if the entry has not
+ * Returns: the read value, or the default value if the entry has not
  * been found in the given group.
  */
 GSList *
@@ -860,7 +860,7 @@ nadp_desktop_file_get_string_list( const NadpDesktopFile *ndf, const gchar *grou
  * @key_found: set to %TRUE if the key has been found, to %FALSE else.
  * @default_value: value to be set if key has not been found.
  *
- * Returns: the readen value, or the default value if the entry has not
+ * Returns: the read value, or the default value if the entry has not
  * been found in the given group.
  */
 guint
diff --git a/src/io-desktop/nadp-reader.c b/src/io-desktop/nadp-reader.c
index e8c50e5..9983c70 100644
--- a/src/io-desktop/nadp-reader.c
+++ b/src/io-desktop/nadp-reader.c
@@ -584,7 +584,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 }
 
 /*
- * called when each NAIFactoryObject object has been readen
+ * called when each NAIFactoryObject object has been read
  */
 void
 nadp_reader_ifactory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *serializable, GSList **messages )
diff --git a/src/io-desktop/nadp-utils.c b/src/io-desktop/nadp-utils.c
index 2dd42b1..9bff43f 100644
--- a/src/io-desktop/nadp-utils.c
+++ b/src/io-desktop/nadp-utils.c
@@ -100,7 +100,7 @@ nadp_utils_uri_delete( const gchar *uri )
  * Returns: %TRUE if the file is writable, %FALSE else.
  *
  * Please note that this type of test is subject to race conditions,
- * as the file may become unwritable after a successfull test,
+ * as the file may become unwritable after a successful test,
  * but before the caller has been able to actually write into it.
  *
  * There is no "super-test". Just try...
diff --git a/src/io-gconf/nagp-reader.c b/src/io-gconf/nagp-reader.c
index c984e29..467ffc0 100644
--- a/src/io-gconf/nagp-reader.c
+++ b/src/io-gconf/nagp-reader.c
@@ -67,7 +67,7 @@ static gboolean      is_key_writable( NagpGConfProvider *gconf, const gchar *key
 /*
  * nagp_iio_provider_read_items:
  *
- * Note that whatever be the version of the readen action, it will be
+ * Note that whatever be the version of the read action, it will be
  * stored as a #NAObjectAction and its set of #NAObjectProfile of the same,
  * latest, version of these classes.
  */
diff --git a/src/io-xml/naxml-reader.c b/src/io-xml/naxml-reader.c
index 04a4065..af6cd80 100644
--- a/src/io-xml/naxml-reader.c
+++ b/src/io-xml/naxml-reader.c
@@ -608,7 +608,7 @@ read_start_profile_attach_profile( NAXMLReader *reader, NAObjectProfile *profile
  * this callback function is called by NAIFactoryObject once for each
  * serializable data for the object
  *
- * Note that some nodes may be readen twice because of multiple definition
+ * Note that some nodes may be read twice because of multiple definition
  * of the same data (e.g. icon which exists in localized and unlocalized
  * versions). So do not remove dealt-with nodes here
  */
@@ -737,7 +737,7 @@ read_data_boxed_from_node( NAXMLReader *reader, xmlChar *path, xmlNode *parent,
 }
 
 /*
- * all serializable data of the object has been readen
+ * all serializable data of the object has been read
  */
 void
 naxml_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, const NAIFactoryObject *object, GSList **messages  )
@@ -770,7 +770,7 @@ naxml_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, c
 }
 
 /*
- * just having readen this NAObjectItem
+ * just having read this NAObjectItem
  * so deals with unlocalized/localized icon name/path
  */
 static void
@@ -890,7 +890,7 @@ read_done_action_load_profile( NAXMLReader *reader, const gchar *profile_id )
 }
 
 /*
- * just having readen this NAObjectProfile
+ * just having read this NAObjectProfile
  * so deals with unlocalized/localized desc-name
  */
 static void
diff --git a/src/nact/nact-gtk-utils.c b/src/nact/nact-gtk-utils.c
index 129a056..0c10863 100644
--- a/src/nact/nact-gtk-utils.c
+++ b/src/nact/nact-gtk-utils.c
@@ -396,7 +396,7 @@ nact_gtk_utils_render( const gchar *name, GtkImage *widget, GtkIconSize size )
  * @dialog_name: the name of the dialog box in Preferences to read/write
  *  its size and position.
  * @entry: the #GtkEntry which is associated with the selected file.
- * @entry_name: the name of the entry in Preferences to be readen/written.
+ * @entry_name: the name of the entry in Preferences to be read/written.
  *
  * Opens a #GtkFileChooserDialog and let the user choose an existing file
  * -> choose and display an existing file name
@@ -422,7 +422,7 @@ nact_gtk_utils_select_file( BaseWindow *window,
  * @dialog_name: the name of the dialog box in Preferences to read/write
  *  its size and position.
  * @entry: the #GtkEntry which is associated with the selected file.
- * @entry_name: the name of the entry in Preferences to be readen/written.
+ * @entry_name: the name of the entry in Preferences to be read/written.
  * @update_preview_cb: the callback function in charge of updating the
  *  preview widget. May be NULL.
  *
@@ -506,7 +506,7 @@ nact_gtk_utils_select_file_with_preview( BaseWindow *window,
  * @dialog_name: the name of the dialog box in Preferences to read/write
  *  its size and position.
  * @entry: the #GtkEntry which is associated with the field.
- * @entry_name: the name of the entry in Preferences to be readen/written.
+ * @entry_name: the name of the entry in Preferences to be read/written.
  * @default_dir_uri: the URI of the directory which should be set in there is
  *  not yet any preference (see @entry_name)
  *
diff --git a/src/nact/nautilus-actions-config-tool.ui b/src/nact/nautilus-actions-config-tool.ui
index 8871ee5..aa36a5e 100644
--- a/src/nact/nautilus-actions-config-tool.ui
+++ b/src/nact/nautilus-actions-config-tool.ui
@@ -1152,7 +1152,7 @@ Leave the field empty to run the command as the current user.</property>
                                           <object class="GtkScrolledWindow" id="scrolledwindow12">
                                             <property name="visible">True</property>
                                             <property name="can_focus">True</property>
-                                            <property name="tooltip_text" translatable="yes">This list lets you determines for which basenames the currently selected item will be displayed in the Nautilus context menu.
+                                            <property name="tooltip_text" translatable="yes">This list lets you determine for which basenames the currently selected item will be displayed in the Nautilus context menu.
 Basenames may use '*' and '?' wildcards.
 Basenames may be negated to specify for which basenames your item must not appear.</property>
                                             <property name="hscrollbar_policy">automatic</property>
@@ -1267,7 +1267,7 @@ Basenames may be negated to specify for which basenames your item must not appea
                     <child type="tab">
                       <object class="GtkLabel" id="label400">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you determines for which basenames the currently selected item will be displayed in the Nautilus context menu.
+                        <property name="tooltip_text" translatable="yes">This tab lets you determine for which basenames the currently selected item will be displayed in the Nautilus context menu.
 Basenames may be negated to specify for which basenames your item must not appear.</property>
                         <property name="label" translatable="yes">_Basenames</property>
                         <property name="use_underline">True</property>
@@ -1319,7 +1319,7 @@ Basenames may be negated to specify for which basenames your item must not appea
                                           <object class="GtkScrolledWindow" id="scrolledwindow8">
                                             <property name="visible">True</property>
                                             <property name="can_focus">True</property>
-                                            <property name="tooltip_text" translatable="yes">This list lets you determines for which mimetypes the currently selected item will be displayed in the Nautilus context menu.
+                                            <property name="tooltip_text" translatable="yes">This list lets you determine for which mimetypes the currently selected item will be displayed in the Nautilus context menu.
 Mimetypes may be specified as '*', '/*', 'group/*' or 'group/subgroup'.
 Mimetypes may be negated to specify for which type of objects your item must not appear.</property>
                                             <property name="hscrollbar_policy">automatic</property>
@@ -1415,7 +1415,7 @@ Mimetypes may be negated to specify for which type of objects your item must not
                     <child type="tab">
                       <object class="GtkLabel" id="label500">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you determines for which mimetypes the currently selected item will be displayed in the Nautilus context menu.
+                        <property name="tooltip_text" translatable="yes">This tab lets you determine for which mimetypes the currently selected item will be displayed in the Nautilus context menu.
 Mimetypes may be specified as '*', '/*', 'group/*' or 'group/subgroup'.
 Mimetypes may be negated to specify for which type of objects your item must not appear.</property>
                         <property name="label" translatable="yes">_Mimetypes</property>
@@ -1468,7 +1468,7 @@ Mimetypes may be negated to specify for which type of objects your item must not
                                           <object class="GtkScrolledWindow" id="scrolledwindow2">
                                             <property name="visible">True</property>
                                             <property name="can_focus">True</property>
-                                            <property name="tooltip_text" translatable="yes">This list lets you determine where (in which folders) the currently selected files must be found in order the item be displayed in the Nautilus context menu.
+                                            <property name="tooltip_text" translatable="yes">This list lets you determine where (in which folders) the currently selected files must be found in order for the item to be displayed in the Nautilus context menu.
 Folders may use '*' or '?' wildcards.
 Folder filters may be negated to specify for which folders your item must not appear.</property>
                                             <property name="hscrollbar_policy">automatic</property>
@@ -1590,7 +1590,7 @@ Folder filters may be negated to specify for which folders your item must not ap
                     <child type="tab">
                       <object class="GtkLabel" id="label600">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you determines where (in which folders) the currently selected files must be found in order the item be displayed in the Nautilus context menu.
+                        <property name="tooltip_text" translatable="yes">This tab lets you determine where (in which folders) the currently selected files must be found in order for the item to be displayed in the Nautilus context menu.
 Folder filters may be negated to specify for which folders your item must not appear.</property>
                         <property name="label" translatable="yes">_Folders</property>
                         <property name="use_underline">True</property>
@@ -1642,7 +1642,7 @@ Folder filters may be negated to specify for which folders your item must not ap
                                           <object class="GtkScrolledWindow" id="scrolledwindow4">
                                             <property name="visible">True</property>
                                             <property name="can_focus">True</property>
-                                            <property name="tooltip_text" translatable="yes">This list lets you determine which schemes the currently selected files must satisfy in order the item be displayed in the Nautilus context menu.
+                                            <property name="tooltip_text" translatable="yes">This list lets you determine which schemes the currently selected files must satisfy in order for the item to be displayed in the Nautilus context menu.
 Filters may be negated to specify for which schemes your item must not appear.</property>
                                             <property name="hscrollbar_policy">automatic</property>
                                             <property name="vscrollbar_policy">automatic</property>
@@ -1766,7 +1766,7 @@ Filters may be negated to specify for which schemes your item must not appear.</
                     <child type="tab">
                       <object class="GtkLabel" id="label700">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you determine which schemes the currently selected files must satisfy in order the item be displayed in the Nautilus context menu.
+                        <property name="tooltip_text" translatable="yes">This tab lets you determine which schemes the currently selected files must satisfy in order for the item to be displayed in the Nautilus context menu.
 Filters may be negated to specify for which schemes your item must not appear.</property>
                         <property name="label" translatable="yes">_Schemes</property>
                         <property name="use_underline">True</property>
@@ -1818,7 +1818,7 @@ Filters may be negated to specify for which schemes your item must not appear.</
                                           <object class="GtkScrolledWindow" id="scrolledwindow10">
                                             <property name="visible">True</property>
                                             <property name="can_focus">True</property>
-                                            <property name="tooltip_text" translatable="yes">This list lets you determine which capabilities the currently selected files must satisfy in order the item be displayed in the Nautilus context menu.
+                                            <property name="tooltip_text" translatable="yes">This list lets you determine which capabilities the currently selected files must satisfy in order for the item to be displayed in the Nautilus context menu.
 Capabilities may be negated to specify for which capabilities your item must not appear.</property>
                                             <property name="hscrollbar_policy">automatic</property>
                                             <property name="vscrollbar_policy">automatic</property>
@@ -1913,7 +1913,7 @@ Capabilities may be negated to specify for which capabilities your item must not
                     <child type="tab">
                       <object class="GtkLabel" id="label800">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you determine which capabilities the currently selected files must satisfy in order the item be displayed in the Nautilus context menu.
+                        <property name="tooltip_text" translatable="yes">This tab lets you determine which capabilities the currently selected files must satisfy in order for the item to be displayed in the Nautilus context menu.
 Filters may be negated to specify for which capabilities your item must not appear.</property>
                         <property name="label" translatable="yes">Ca_pabilities</property>
                         <property name="use_underline">True</property>
@@ -2345,7 +2345,7 @@ This may be used for example for testing the presence of a prerequisite daemon.<
                     <child type="tab">
                       <object class="GtkLabel" id="label900">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you determine some advanced conditions the currently selected files must satisfy in order the item be displayed in the file manager context menu.</property>
+                        <property name="tooltip_text" translatable="yes">This tab lets you determine some advanced conditions the currently selected files must satisfy in order for the item to be displayed in the file manager context menu.</property>
                         <property name="label" translatable="yes">_Environment</property>
                         <property name="use_underline">True</property>
                       </object>
@@ -2620,7 +2620,7 @@ There may be multiple reasons for why an item cannot be edited. See your User's
                     <child type="tab">
                       <object class="GtkLabel" id="labelA00">
                         <property name="visible">True</property>
-                        <property name="tooltip_text" translatable="yes">This tab lets you edit some miscellaneous properties, and access to some non-modifiable information.</property>
+                        <property name="tooltip_text" translatable="yes">This tab lets you edit some miscellaneous properties, and access some non-modifiable information.</property>
                         <property name="label" translatable="yes">P_roperties</property>
                         <property name="use_underline">True</property>
                       </object>
diff --git a/src/plugin-menu/nautilus-actions.c b/src/plugin-menu/nautilus-actions.c
index 53697db..02bc071 100644
--- a/src/plugin-menu/nautilus-actions.c
+++ b/src/plugin-menu/nautilus-actions.c
@@ -526,7 +526,7 @@ get_menus_items( NautilusActions *plugin, guint target, GList *selection )
 /*
  * create a copy of the tree where almost all fields which may embed
  * parameters have been expanded
- * here, 'almost' should be readen as:
+ * here, 'almost' should be read as:
  * - all displayable fields, or fields which may have an impact on the display
  *   (e.g. label, tooltip, icon name)
  * - all fields which we do not need later
diff --git a/src/utils/nautilus-actions-new.c b/src/utils/nautilus-actions-new.c
index 8a865b7..6372f72 100644
--- a/src/utils/nautilus-actions-new.c
+++ b/src/utils/nautilus-actions-new.c
@@ -354,7 +354,7 @@ init_options( void )
 }
 
 /*
- * allocate a new action, and fill it with values readen from command-line
+ * allocate a new action, and fill it with values read from command-line
  */
 static NAObjectAction *
 get_action_from_cmdline( void )
diff --git a/src/utils/nautilus-actions-run.c b/src/utils/nautilus-actions-run.c
index 7073cef..92e7169 100644
--- a/src/utils/nautilus-actions-run.c
+++ b/src/utils/nautilus-actions-run.c
@@ -57,7 +57,7 @@ static gboolean   version          = FALSE;
 static GOptionEntry entries[] = {
 
 	{ "id"                   , 'i', 0, G_OPTION_ARG_STRING        , &id,
-			N_( "The internal identifiant of the action to be launched" ), N_( "<STRING>" ) },
+			N_( "The internal identifier of the action to be launched" ), N_( "<STRING>" ) },
 	{ "target"               , 't', 0, G_OPTION_ARG_FILENAME_ARRAY, &targets_array,
 			N_( "A target, file or folder, for the action. More than one options may be specified" ), N_( "<URI>" ) },
 	{ NULL }
diff --git a/tools/check-headers.sh b/tools/check-headers.sh
index b44cb6e..6ef51b6 100755
--- a/tools/check-headers.sh
+++ b/tools/check-headers.sh
@@ -95,7 +95,7 @@ function msg_help
 	echo "
  This script checks for header files consistency and completeness.
  It ensures that each header files itself includes the set of prequisite
- header files in order the tested header be auto-sufficent.
+ header files so that the tested header is auto-sufficent.
 
  Usage: ${my_cmd} [options]
    --[no]help                print this message, and exit [${opt_help_def}]
diff --git a/tools/init-finalize-diff.sh b/tools/init-finalize-diff.sh
index 86ae174..fa09ee8 100755
--- a/tools/init-finalize-diff.sh
+++ b/tools/init-finalize-diff.sh
@@ -135,7 +135,7 @@ grep -En "instance_init|instance_${check_for}" ${1} | grep -vE 'quitting main wi
 	echo "${numline} ${fn_name} ${obj_address} ${class} ${prefix} ${nature} ${reused}" >> ${tmp1}
 done
 count=$(wc -l ${tmp1} | awk '{ print $1 }')
-echo " ${count} readen lines"
+echo " ${count} lines read"
 #cat ${tmp1}
 #exit
 
@@ -163,9 +163,9 @@ cat ${tmp2} | while read line; do
 			fn_prefix_init=$(echo ${line} | awk '{ print $5 }')
 			line_init="${line}"
 		else
 			# init line being readen, but previous was also an init line
 			# say previous was an error
 			# and restart with init line being readen
 			class=$(echo ${line_init} | awk '{ print $4 }')
 			if [ "$(str_grep list_undisposed ${obj_address_init})" = "" ]; then
 				num=$(echo ${line_init} | awk '{ print $1 }')
@@ -183,7 +183,7 @@ cat ${tmp2} | while read line; do
 		fi
 	else
 		if [ "${line_init}" = "" ]; then
 			# dispose line being readen but previous was also a dispose line
 			# just signals the dispose line is an error
 			echo "warning: unwaited line: ${line}"
 			count_inc count_warns
@@ -163,9 +163,9 @@ cat ${tmp2} | while read line; do
 			line_init="${line}"
 		else
-			# init line being readen, but previous was also an init line
+			# init line being read, but previous was also an init line
 			# say previous was an error
@@ -163,9 +163,9 @@ cat ${tmp2} | while read line; do
 			# say previous was an error
-			# and restart with init line being readen
+			# and restart with init line being read
 			class=$(echo ${line_init} | awk '{ print $4 }')
 			if [ "$(str_grep list_undisposed ${obj_address_init})" = "" ]; then
@@ -183,7 +183,7 @@ cat ${tmp2} | while read line; do
 	else
 		if [ "${line_init}" = "" ]; then
-			# dispose line being readen but previous was also a dispose line
+			# dispose line being read but previous was also a dispose line
 			# just signals the dispose line is an error
 			echo "warning: unwaited line: ${line}"



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]